@@ -267,10 +267,20 @@ class DefaultGraphDrawer(AbstractCairoGraphDrawer):
         if "mark_groups" in kwds:
             mark_groups = kwds["mark_groups"]
 
+            # Deferred import to avoid a cycle in the import graph
+            from igraph.clustering import VertexClustering, VertexCover
+
             # Figure out what to do with mark_groups in order to be able to
             # iterate over it and get memberlist-color pairs
             if isinstance(mark_groups, dict):
+                # Dictionary mapping vertex indices or tuples of vertex
+                # indices to colors
                 group_iter = iter(mark_groups.items())
+            elif isinstance(mark_groups, (VertexClustering, VertexCover)):
+                # Vertex clustering
+                group_iter = (
+                    (group, color) for color, group in enumerate(mark_groups)
+                )
             elif hasattr(mark_groups, "__iter__"):
                 # Lists, tuples, iterators etc
                 group_iter = iter(mark_groups)
@@ -358,10 +368,6 @@ class DefaultGraphDrawer(AbstractCairoGraphDrawer):
         for vertex, visual_vertex, coords in vertex_coord_iter:
             drawer_method(visual_vertex, vertex, coords)
 
-        # Set the font we will use to draw the labels
-        context.select_font_face("sans-serif", cairo.FONT_SLANT_NORMAL, \
-            cairo.FONT_WEIGHT_NORMAL)
-
         # Decide whether the labels have to be wrapped
         wrap = kwds.get("wrap_labels")
         if wrap is None:
@@ -382,6 +388,9 @@ class DefaultGraphDrawer(AbstractCairoGraphDrawer):
             if vertex.label is None:
                 continue
 
+            # Set the font family, size, color and text
+            context.select_font_face(vertex.font, \
+                cairo.FONT_SLANT_NORMAL, cairo.FONT_WEIGHT_NORMAL)
             context.set_font_size(vertex.label_size)
             context.set_source_rgba(*vertex.label_color)
             label_drawer.text = vertex.label
@@ -454,7 +463,9 @@ class DefaultGraphDrawer(AbstractCairoGraphDrawer):
             if visual_edge.label is None:
                 continue
 
-            # Set the font size, color and text
+            # Set the font family, size, color and text
+            context.select_font_face(visual_edge.font, \
+                cairo.FONT_SLANT_NORMAL, cairo.FONT_WEIGHT_NORMAL)
             context.set_font_size(visual_edge.label_size)
             context.set_source_rgba(*visual_edge.label_color)
             label_drawer.text = visual_edge.label
@@ -915,4 +926,3 @@ class GephiGraphStreamingDrawer(AbstractGraphDrawer):
               will be used to encode the JSON objects.
         """
         self.streamer.post(graph, self.connection, encoder=kwds.get("encoder"))
-
